@@ -6,7 +6,7 @@ import (
 )
 
 // All of the following methods error out on unsupported platforms
-var ErrUnsupportedPlatform = errors.New("Unsupported platform: " + runtime.GOOS)
+var ErrUnsupportedPlatform = errors.New("unsupported platform: " + runtime.GOOS)
 
 type fallbackServiceProvider struct{}
 
