@@ -186,14 +186,25 @@ func (s *SecretService) CreateItem(collection dbus.BusObject, label string, attr
 // the prompt to the user.
 func (s *SecretService) handlePrompt(prompt dbus.ObjectPath) (bool, dbus.Variant, error) {
 	if prompt != dbus.ObjectPath("/") {
-		err := s.Object(serviceName, prompt).Call(promptInterface+".Prompt", 0, "").Err
+		err := s.AddMatchSignal(dbus.WithMatchObjectPath(prompt),
+			dbus.WithMatchInterface(promptInterface),
+		)
 		if err != nil {
 			return false, dbus.MakeVariant(""), err
 		}
 
+		defer func(s *SecretService, options ...dbus.MatchOption) {
+			_ = s.RemoveMatchSignal(options...)
+		}(s, dbus.WithMatchObjectPath(prompt), dbus.WithMatchInterface(promptInterface))
+
 		promptSignal := make(chan *dbus.Signal, 1)
 		s.Signal(promptSignal)
 
+		err = s.Object(serviceName, prompt).Call(promptInterface+".Prompt", 0, "").Err
+		if err != nil {
+			return false, dbus.MakeVariant(""), err
+		}
+
 		signal := <-promptSignal
 		switch signal.Name {
 		case promptInterface + ".Completed":
